%feature("docstring") OT::AbsoluteExponential
"Absolute exponential covariance model.

Available constructors:
    AbsoluteExponential(*dim=1, theta=10*)

    AbsoluteExponential(*scale*)

    AbsoluteExponential(*scale, sigma*)

Parameters
----------
dim : int, :math:`dim \\\\geq 0`
    Input dimension.
theta : float
    Coefficient :math:`\\\\theta` of the covariance function, default is 10.
scale : sequence of floats
    Scale coefficients :math:`\\\\theta`.
    The spatial dimension is the size of vector.
sigma : sequence of floats
    Amplitude coefficients :math:`\\\\sigma`.
    Should be of size 1

Notes
-----
The covariance function of input dimension *dim* is:

.. math::

    C(s, t) = \\\\sigma^2 e^{- ||\\\\frac{s-t}{\\\\theta}||_{1} }

where the division is vectorial, :math:`\\\\sigma` is the amplitude (default value is 1.0). Note that the model is unidimensional.

See Also
--------
CovarianceModel, SquaredExponential, GeneralizedExponential, MaternModel

Examples
--------
>>> import openturns as ot
>>> covarianceModel = ot.AbsoluteExponential(2)
>>> t = [0.1, 0.3]
>>> s = [0.2, 0.4]
>>> print(covarianceModel(s, t))
[[ 0.980199 ]]
>>> tau = [0.1, 0.3]
>>> print(covarianceModel(tau))
[[ 0.960789 ]]"
