%feature("docstring") OT::Arcsine
"Arcsine distribution.

Available constructors:
    Arcsine(*arg1=-1.0, arg2=1.0, parameters_set=ot.Arcsine.AB*)

Parameters
----------
arg1 : float
    If *parameters_set == ot.Arcsine.AB*: lower bound (:math:`a`).

    If *parameters_set == ot.Arcsine.MUSIGMA*: mean.
arg2 : float
    If *parameters_set == ot.Arcsine.AB*: upper bound (:math:`b > a`).

    If *parameters_set == ot.Arcsine.MUSIGMA*: standard deviation :math:`\\\\sigma > 0`.
parameters_set : int, optional
    Integer telling which parameters set is used for defining the
    distribution (amongst `ot.Arcsine.AB, ot.Arcsine.MUSIGMA`).

Notes
-----
Its probability density function is defined as:

.. math::

    f_X(x) = \\\\frac{1}{\\\\pi \\\\sqrt{(x - a)(b - x)}},
             \\\\quad x \\\\in [a, b]

with :math:`a < b`.

Its first moments are:

.. math::
    :nowrap:

    \\\\begin{eqnarray*}
        \\\\Expect{X} & = & \\\\frac{a + b}{2} \\\\\\\\
        \\\\Var{X} & = & \\\\frac{(b - a)^2}{8}
    \\\\end{eqnarray*}

Examples
--------
Create a distribution:

>>> import openturns as ot
>>> distribution = ot.Arcsine(2., 3.)

Draw a sample:

>>> sample = distribution.getSample(10)"

// ---------------------------------------------------------------------

%feature("docstring") OT::Arcsine::getA
"Accessor to the distribution's lower bound.

Returns
-------
a : float
    Lower bound."

// ---------------------------------------------------------------------

%feature("docstring") OT::Arcsine::getB
"Accessor to the distribution's upper bound.

Returns
-------
b : float
    Upper bound."

// ---------------------------------------------------------------------

%feature("docstring") OT::Arcsine::getMu
"Accessor to the distribution's mean.

Returns
-------
mu : float
    Mean."

// ---------------------------------------------------------------------

%feature("docstring") OT::Arcsine::getSigma
"Accessor to the distribution's standard deviation.

Returns
-------
sigma : float
    Standard deviation."

// ---------------------------------------------------------------------

%feature("docstring") OT::Arcsine::setA
"Accessor to the distribution's lower bound.

Parameters
----------
a : float, :math:`a < b`
    Lower bound."

// ---------------------------------------------------------------------

%feature("docstring") OT::Arcsine::setB
"Accessor to the distribution's upper bound.

Parameters
----------
b : float, :math:`a < b`
    Upper bound."

// ---------------------------------------------------------------------

%feature("docstring") OT::Arcsine::setMu
"Accessor to the distribution's mean.

Parameters
----------
mu : float
    Mean."

// ---------------------------------------------------------------------

%feature("docstring") OT::Arcsine::setSigma
"Accessor to the distribution's standard deviation.

Parameters
----------
sigma : float, :math:`\\\\sigma > 0`
    Standard deviation."