%define OT_DistributionFactory_doc
"Base class for probability distribution factories.

Notes
-----
This class generally describes the factory mechanism of each OpenTURNS
distribution. Refer to the Reference Guide to have information on the specific
estimators used for each distribution.
"
%enddef
%feature("docstring") OT::DistributionFactoryImplementation
OT_DistributionFactory_doc

// ---------------------------------------------------------------------

%define OT_DistributionFactory_build_doc
"build the distribution.

**Available usages**:

    build(*sample*)

    build(*param*)

Parameters
----------
sample : 2-d sequence of float
    Sample from which the distribution parameters are estimated.
param : Collection of :class:`~openturns.NumericalPointWithDescription`
    A vector of parameters of the distribution.

Returns
-------
dist : :class:`~openturns.Distribution`
    The built distribution."
%enddef
%feature("docstring") OT::DistributionFactoryImplementation::build
OT_DistributionFactory_build_doc

// ---------------------------------------------------------------------

%define OT_DistributionFactory_buildEstimator_doc
"Build the distribution and the distribution of its parameter.

If the distribution is estimated by method of moments, the distribution of the
parameter is gaussian and estimated by bootstrap.
If the distribution is estimated by maximum likelihood and the distribution
is regular the distribution of the parameter is gaussian and its covariance
matrix is the Fisher information matrix.
In other cases, the distribution of parameter is estimated by bootstrap with
:class:`~openturns.KernelSmoothing`.
When specifying the parametrization, the distribution of the parameters is
estimated by :class:`~openturns.KernelSmoothing` unless the distribution of
parameters is gaussian, in which case the parameters distribution is gaussian
too.

Parameters
----------
sample : 2-d sequence of float
    Sample from which the distribution parameters are estimated.
parameters : :class:`~openturns.DistributionParameters`
    Optional, the parametrization.

Returns
-------
parameterDistribution : :class:`~openturns.DistributionFactoryResult`
    The results."
%enddef
%feature("docstring") OT::DistributionFactoryImplementation::buildEstimator
OT_DistributionFactory_buildEstimator_doc

// ---------------------------------------------------------------------

%define OT_DistributionFactory_getBootstrapSize_doc
"Accessor to the bootstrap size.

Returns
-------
size : integer
    Size of the bootstrap."
%enddef
%feature("docstring") OT::DistributionFactoryImplementation::getBootstrapSize
OT_DistributionFactory_getBootstrapSize_doc

// ---------------------------------------------------------------------

%define OT_DistributionFactory_setBootstrapSize_doc
"Accessor to the bootstrap size.

Parameters
----------
size : integer
    Size of the bootstrap."
%enddef
%feature("docstring") OT::DistributionFactoryImplementation::setBootstrapSize
OT_DistributionFactory_setBootstrapSize_doc

// ---------------------------------------------------------------------

%define OT_DistributionFactory_setKnownParameter_doc
"Accessor to the known parameters.

Parameters
----------
values : sequence of float
    Values of fixed parameters.
indices : sequence of int
    Indices of fixed parameters."
%enddef
%feature("docstring") OT::DistributionFactoryImplementation::setKnownParameter
OT_DistributionFactory_setKnownParameter_doc

// ---------------------------------------------------------------------

%define OT_DistributionFactory_getKnownParameterValues_doc
"Accessor to the known parameters indices.

Returns
-------
values : :class:`~openturns.NumericalPoint`
    Values of fixed parameters."
%enddef
%feature("docstring") OT::DistributionFactoryImplementation::getKnownParameterValues
OT_DistributionFactory_getKnownParameterValues_doc

// ---------------------------------------------------------------------

%define OT_DistributionFactory_getKnownParameterIndices_doc
"Accessor to the known parameters indices.

Returns
-------
indices : :class:`~openturns.Indices`
    Indices of fixed parameters."
%enddef
%feature("docstring") OT::DistributionFactoryImplementation::getKnownParameterIndices
OT_DistributionFactory_getKnownParameterIndices_doc

