%feature("docstring") OT::GeneralizedExponential
"Absolute exponential covariance model.

Available constructors:
    GeneralizedExponential(*dim=1, theta=10, p=1*)

    GeneralizedExponential(*scale, p*)

    GeneralizedExponential(*scale, sigma, p*)

Parameters
----------
dim : int, :math:`dim \\\\geq 0`
    Input dimension.
theta : float
    Coefficient :math:`\\\\theta` of the covariance function, default is 10.
p : float
    Exponent :math:`p` of the covariance function, default is 1.
scale : sequence of floats
    Scale coefficients :math:`\\\\theta`.
    The spatial dimension is the size of vector.
sigma : sequence of floats
    Amplitude coefficients :math:`\\\\sigma`.
    Should be of size 1


Notes
-----
The covariance function of input dimension *dim* is:

.. math::

    C(s, t) = \\\\sigma^2 e^{- \\\\left(||\\\\frac{s-t}{\\\\theta}\\\\right||_{2})^p}

where the division is vectorial, :math:`\\\\sigma` is the amplitude (default value is 1.0). Note that the model is unidimensional.

See Also
--------
CovarianceModel, SquaredExponential, AbsoluteExponential, MaternModel

Examples
--------
>>> import openturns as ot
>>> covarianceModel = ot.GeneralizedExponential(2, 1, 3)
>>> t = [0.1, 0.3]
>>> s = [0.2, 0.4]
>>> print(covarianceModel(s, t))
[[ 0.997176 ]]
>>> tau = [0.1, 0.3]
>>> print(covarianceModel(tau))
[[ 0.968872 ]]"
