%feature("docstring") OT::MaternModel
"Matern covariance model.

Available constructors:
    MaternModel(*dim=1*)

    MaternModel(*dim, theta, nu*)

    MaternModel(*scale, nu*)

    MaternModel(*scale, sigma, nu*)

Parameters
----------
dim : int, :math:`dim \\\\geq 0`
    Input dimension.
theta : float
    Scale coefficient :math:`\\\\theta` of the covariance function.
nu : float
    Coefficient :math:`\\\\nu` of the covariance function.
scale : sequence of floats
    Scale coefficients :math:`\\\\theta`.
    The spatial dimension is the size of vector.
sigma : sequence of floats
    Amplitude coefficients :math:`\\\\sigma`.
    Should be of size 1

Notes
-----
The covariance function of input dimension *dim* is:

.. math::

    C(s, t) = \\\\sigma^2 \\\\frac{1}{\\\\Gamma(\\\\nu) 2^{\\\\nu-1}} \\\\left(\\\\sqrt{2 \\\\nu} ||\\\\frac{s-t}{\\\\theta}||\\\\right)^{\\\\nu} K_{\\\\nu} \\\\left(\\\\sqrt{2 \\\\nu} ||\\\\frac{s-t}{\\\\theta}||\\\\right)

where the division is vectorial, :math:`\\\\sigma` is the amplitude (default value is 1.0). Note that the model is unidimensional.

See Also
--------
CovarianceModel, SquaredExponential, AbsoluteExponential, GeneralizedExponential

Examples
--------
>>> import openturns as ot
>>> covarianceModel = ot.MaternModel(2)
>>> t = [0.1, 0.3]
>>> s = [0.2, 0.4]
>>> print(covarianceModel(s, t))
[[ 0.999705 ]]
>>> tau = [0.1, 0.3]
>>> print(covarianceModel(tau))
[[ 0.998554 ]]"
