%feature("docstring") OT::P1LagrangeEvaluationImplementation
"Data based math evaluation implementation.

Available constructors:

    P1LagrangeEvaluationImplementation(*field*)

Parameters
----------
field : :class:`~openturns.Field`
    Field :math:`\\\\cF` defining the parameters of a P1 Lagrange interpolation function.

See also
--------
NumericalMathFunction, AggregatedNumericalMathEvaluationImplementation, DualLinearCombinationEvaluationImplementation,
LinearNumericalMathFunction

Notes
-----
It returns a :class:`~openturns.NumericalMathFunction` that implements the P-1 Lagrange interpolation function :math:`f : \\\\cD_N \\\\rightarrow \\\\Rset^p` :

.. math::
    \\\\forall \\\\vect{x} \\\\in \\\\Rset^n, f(\\\\vect{x}) = \\\\sum_{\\\\vect{\\\\xi}_i\\\\in\\\\cV(\\\\vect{x})}\\\\alpha_i f(\\\\vect{\\\\xi}_i)

where :math:`\\\\cD_N` is a :class:`~openturns.Mesh`, :math:`\\\\cV(\\\\vect{x})` is the simplex in :math:`\\\\cD_N` that contains :math:`\\\\vect{x}`, :math:`\\\\alpha_i` are the barycentric coordinates of :math:`\\\\vect{x}` wrt the vertices :math:`\\\\vect{\\\\xi}_i` of :math:`\\\\cV(\\\\vect{x})`:

.. math::
    \\\\vect{x}=\\\\sum_{\\\\vect{\\\\xi}_i\\\\in\\\\cV(\\\\vect{x})}\\\\alpha_i\\\\vect{\\\\xi}_i

Examples
--------
Create a Karhunen-Loeve P1 factory:

>>> import openturns as ot
>>> field = ot.Field(ot.RegularGrid(0.0, 1.0, 4), [[0.5], [1.5], [1.0], [-0.5]])
>>> evaluation = ot.P1LagrangeEvaluationImplementation(field)
>>> print(evaluation([2.3]))
[0.55]"
// ---------------------------------------------------------------------

%feature("docstring") OT::P1LagrangeEvaluationImplementation::getField
"Accessor to the field defining the functions.

Returns
-------
field : :class:`~openturns.Field`
    The field defining the function."

// ---------------------------------------------------------------------

%feature("docstring") OT::P1LagrangeEvaluationImplementation::setField
"Accessor to the field defining the functions.

Parameters
----------
field : :class:`~openturns.Field`
    The field defining the function."
