%feature("docstring") OT::SphericalModel
"Spherical covariance model.

Available constructors:
    SphericalModel(*dim=1*)
    SphericalModel(*dim=1, amplitude, scale, a*)

Parameters
----------
dim : int, :math:`dim \\\\geq 0`
    Input dimension (spatial dimension).
amplitude : sequence of float
    Vector :math:`\\\\vect{a}` of dimension :math:`d`.
    Amplitude of the covariance model
scale : sequence of float
    Vector :math:`\\\\vect{\\\\lambda}` of dimension :math:`spatialDim`.
    Scale parameter
a : float
    Positive. Ray of the sphere on which the covariance model is not zero
    Default is 1.

Notes
-----
The covariance function of input dimension *dim* is defined on a sphere of ray :math:`a` (for :math:`||\\\\frac{s-t}{\\\\theta}|| \\\\leq a`) as follows:

.. math::

   C(s, t) = \\\\sigma^2 * (1 - \\\\frac{1}{2a} ||\\\\frac{s-t}{\\\\theta}|| ) * (3 - ||\\\\frac{s-t}{\\\\theta}||^2)

where the division is vectorial, :math:`\\\\theta` is the scale parameter, :math:`\\\\sigma` is the amplitude (default value is 1.0). Note that the model is unidimensional. and equals 0 outside the sphere.

See Also
--------
CovarianceModel, SquaredExponential, GeneralizedExponential, MaternModel

Examples
--------
>>> import openturns as ot
>>> covarianceModel = ot.SphericalModel(2, [1.0], [0.2, 0.3])
>>> t = [0.1, 0.3]
>>> s = [0.2, 0.4]
>>> print(covarianceModel(s, t))
[[ 0.0393519 ]]
>>> tau = [0.1, 0.3]
>>> print(covarianceModel(tau))
[[ 0 ]]"
